RustLibApi class abstract
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
crateApiSimpleAccountSetup(
{required String uri, required String username, required String password}) → Future< int> -
crateApiSimpleDestroyPjsua(
) → Future< int> -
crateApiSimpleHangupCall(
{required int callId}) → Future< void> -
crateApiSimpleInitApp(
) → Future< void> -
crateApiSimpleInitPjsua(
{required int localPort, required OnIncommingCall incomingCallStrategy, required String stunSrv}) → Future< int> -
crateApiSimpleMakeCall(
{required String phoneNumber, required String domain}) → Future< int> -
crateApiSimpleMarkCallAlive(
{required int callId}) → Future< void> -
crateApiSimpleRegisterAccountStream(
) → Stream< AccountInfo> -
crateApiSimpleRegisterCallStream(
) → Stream< CallInfo> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited