SIPService class
Constructors
Properties
- accountID ↔ int
-
getter/setter pair
-
accountStream
↔ Stream<
AccountInfo> -
getter/setter pair
-
callIds
→ Map<
int, CallInfo> -
final
-
callStateBroadcast
↔ BehaviorSubject<
CallInfo> -
getter/setter pair
-
callStream
↔ Stream<
CallInfo> -
getter/setter pair
- error ↔ String?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- registered ↔ bool
-
getter/setter pair
- registrarUri ↔ String
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
call(
String phoneNumber, String domain) → Future< int> -
dispose(
) → Future< void> -
hangup(
int callId) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
registerAccount(
{required String uri, required String username, required String password}) → Future< int> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- initialized ↔ bool?
-
getter/setter pair
- initializeErr ↔ String?
-
getter/setter pair
Static Methods
-
init(
{int localPort = 5060, OnIncommingCall incomingCallStrategy = OnIncommingCall.ignore, String stunSrv = 'stun.l.google.com:19302'}) → Future< SIPService>